# shelter

- started with: 100 VAC, 1.59 kΩ ~= 6.3 w - heat was not noticeable.
- 2025-11-07: 200 VAC, 1.59 kΩ ~= 25.2 w - heat is noticeable. ✅

- [AI convo](https://chatgpt.com/c/68df585e-9a68-832f-b22e-481af04c377e)

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/01.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/01.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/02.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/02.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/03.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/03.png?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/04.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/04.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251005_180841.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251005_180841.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181432.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181432.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181509.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181509.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181554.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181554.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251028_113245.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251028_113245.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251103_182323.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251103_182323.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251104_000755.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251104_000755.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000501.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000501.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000641.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000641.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002124.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002124.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002639.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002639.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251124_094744.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251124_094744.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251202_101949.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251202_101949.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251202_102912.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251202_102912.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_095746.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_095746.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100222.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100222.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100305.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100305.jpg?raw=true) |

## parts

continues [v1](./parts-v1.md).

|   |   |   |   |
| --- | --- | --- | --- |
| [`220VAC dimmer`](../parts/220VAC-dimmer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/220VAC-dimmer.jpeg?raw=true)](../parts/220VAC-dimmer.md)  | [`ceramic terminal`](../parts/ceramic-terminal.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ceramic-terminal.jpg?raw=true)](../parts/ceramic-terminal.md)  | [`mountable digital thermometer`](../parts/mountable-digital-thermometer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mountable-digital-thermometer.jpeg?raw=true)](../parts/mountable-digital-thermometer.md)  | [`resistance heating wire`](../parts/resistance-heating-wire.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/resistance-heating-wire.jpg?raw=true)](../parts/resistance-heating-wire.md) 1.59 kΩ |

1. [220VAC dimmer](../parts/220VAC-dimmer.md).
1. [ceramic terminal](../parts/ceramic-terminal.md).
1. [mountable digital thermometer](../parts/mountable-digital-thermometer.md).
1. [resistance heating wire](../parts/resistance-heating-wire.md): 1.59 kΩ.
